# Easier Pygame

## Table of Contents

- [About](#about)
- [Getting Started](#getting_started)
- [Contributing](contributing.md)

## About <a name = "about"></a>

This python library is a wrapper for the pygame library.
It provides a simple interface for creating games in pygame without all the bloat code that needs to be written for pygame to work.

## Getting Started <a name = "getting_started"></a>

to use this package go to your console and write: 
```
pip install pygame-easier
```

if it doesn't work try: 
```
python -m pip install pygame-easier
```

### Prerequisites

before you start you need to install:
* [python](https://www.python.org/downloads/)
* [pip](https://pip.pypa.io/en/stable/getting-started/)
* [pygame](https://www.pygame.org/wiki/GettingStarted)
* [moviepy](https://zulko.github.io/moviepy/install.html)
